SyncStreamReadHalf

Struct SyncStreamReadHalf 

pub struct SyncStreamReadHalf<S> { /* private fields */ }
Available on crate features io and compat only.
Read half of a SyncStream after splitting.

Implementations

Source

impl<S> SyncStreamReadHalf<S>

pub fn get_ref(&self) -> &S

Returns a reference to the underlying stream.

pub fn get_mut(&mut self) -> &mut S

Returns a mutable reference to the underlying stream.

pub fn into_inner(self) -> S

Consumes the SyncStreamReadHalf, returning the underlying stream.

pub fn into_parts(self) -> (S, Vec<u8>)

Consumes the SyncStream, returning the underlying stream and any unread buffered data.

If the read buffer is currently lent to an IO operation, the returned Vec will be empty.

pub fn is_eof(&self) -> bool

Returns true if the stream has reached EOF.

pub fn read_buf_uninit( &mut self, buf: &mut [MaybeUninit<u8>], ) -> Result<usize, Error>

Pull some bytes from this source into the specified buffer.

Source

impl<S> SyncStreamReadHalf<S>
where S: AsyncRead,